@@ -3,7 +3,7 @@ import typing
 from .element import Element
 from .field import ExtractedField
 
-from pydantic import model_serializer, model_validator
+from pydantic import model_serializer, model_validator, PrivateAttr
 
 
 class Group(Element):
@@ -11,6 +11,8 @@ class Group(Element):
         str, typing.Union[Element, typing.Dict[str, Element], typing.Sequence[Element]]
     ] = {}
 
+    _remove_fields: bool = PrivateAttr(default=True)
+
     @model_validator(mode="before")
     @classmethod
     def _inflate_fields(
@@ -52,6 +54,9 @@ class Group(Element):
         self,
         handler: typing.Callable[[typing.Any], typing.Dict[str, typing.Any]],
     ) -> typing.Dict[str, typing.Any]:
+        if not self._remove_fields:
+            return handler(self)
+
         data = handler(self)
 
         raw_fields = typing.cast(
@@ -63,6 +68,18 @@ class Group(Element):
 
         return data
 
+    @property
+    def remove_fields(self) -> bool:
+        return self._remove_fields
+
+    @remove_fields.setter
+    def remove_fields(self, value: bool) -> None:
+        self._remove_fields = value
+
+    @remove_fields.deleter
+    def remove_fields(self) -> None:
+        del self._remove_fields
+
     def get(
         self, name: str
     ) -> typing.Optional[
@@ -105,6 +122,19 @@ class Group(Element):
 
         return obj
 
+    def render(self) -> typing.Optional[str]:
+        if not self.prompt:
+            return None
+        if not self.prompt.attr_name:
+            return None
+        if not self.prompt.instructions:
+            return None
+
+        return f"""
+# {self.prompt.attr_name} Definition
+
+{self.prompt.instructions}"""
+
     def set(
         self,
         name: str,
