@@ -1,12 +1,10 @@
 from .utility import (
-    class_fields,
     clean_json,
     coerce_numeric_string,
     str_to_type_sequence,
 )
 
 __all__ = [
-    "class_fields",
     "clean_json",
     "coerce_numeric_string",
     "str_to_type_sequence",
