@@ -57,6 +57,7 @@ MAX_BATCH_SIZE = 50
 MIN_BATCH_SIZE = 1
 MAX_BATCH_SIZE_BYTES = 50 * 1024 * 1024
 
+
 def get_presigned_url(
     endpoint: str,
     file_name: str,
@@ -68,6 +69,7 @@ def get_presigned_url(
 
     return response.json()
 
+
 def strip_query_params(
     url: str,
 ) -> str:
@@ -76,6 +78,7 @@ def strip_query_params(
 
     return clean_url
 
+
 def prep_documents(
     documents: typing.Sequence[Document],
 ) -> typing.Tuple[
@@ -127,16 +130,16 @@ def prep_documents(
 
 def split_doc(file: Path) -> typing.List[Path]:
     if file.is_file() and (
-        file.suffix.lower() in ALLOWED_SUFFIXES
-        or file.suffix.lower() in SUFFIX_ALIASES
+        file.suffix.lower() in ALLOWED_SUFFIXES or file.suffix.lower() in SUFFIX_ALIASES
     ):
         if file.suffix.lower() in CSV_SPLITS:
             return CSVSplitter(filepath=file).split()
         elif file.suffix.lower() in TSV_SPLITS:
-            return CSVSplitter(filepath=file, delimiter='\t').split()
+            return CSVSplitter(filepath=file, delimiter="\t").split()
         return [file]
     return []
 
+
 class GroundX(GroundXBase):
     def ingest(
         self,
@@ -147,6 +150,7 @@ class GroundX(GroundXBase):
         upload_api: str = "https://api.eyelevel.ai/upload/file",
         callback_url: typing.Optional[str] = None,
         callback_data: typing.Optional[str] = None,
+        override_batch_size: typing.Optional[bool] = False,
         request_options: typing.Optional[RequestOptions] = None,
     ) -> IngestResponse:
         """
@@ -206,12 +210,22 @@ class GroundX(GroundXBase):
         if len(remote_documents) + len(local_documents) == 0:
             raise ValueError("No valid documents were provided")
 
+        max_n = MAX_BATCH_SIZE
+        if override_batch_size:
+            max_n = 1000
+
         if wait_for_complete:
-            with tqdm(total=len(remote_documents) + len(local_documents), desc="Ingesting Files", unit="file") as pbar:
-                n = max(MIN_BATCH_SIZE, min(batch_size or MIN_BATCH_SIZE, MAX_BATCH_SIZE))
+            with tqdm(
+                total=len(remote_documents) + len(local_documents),
+                desc="Ingesting Files",
+                unit="file",
+            ) as pbar:
+                n = max(MIN_BATCH_SIZE, min(batch_size or MIN_BATCH_SIZE, max_n))
 
                 remote_batch: typing.List[IngestRemoteDocument] = []
-                ingest = IngestResponse(ingest=IngestStatus(process_id="",status="queued"))
+                ingest = IngestResponse(
+                    ingest=IngestStatus(process_id="", status="queued")
+                )
 
                 progress = float(len(remote_documents))
                 for rd in remote_documents:
@@ -239,7 +253,6 @@ class GroundX(GroundXBase):
                     )
                     ingest, progress = self._monitor_batch(ingest, progress, pbar)
 
-
                 if progress > 0:
                     pbar.update(progress)
 
@@ -251,8 +264,12 @@ class GroundX(GroundXBase):
                     fp = Path(os.path.expanduser(ld.file_path))
                     file_size = fp.stat().st_size
 
-                    if (current_batch_size + file_size > MAX_BATCH_SIZE_BYTES) or (len(local_batch) >= n):
-                        up_docs, progress = self._process_local(local_batch, upload_api, progress, pbar)
+                    if (current_batch_size + file_size > MAX_BATCH_SIZE_BYTES) or (
+                        len(local_batch) >= n
+                    ):
+                        up_docs, progress = self._process_local(
+                            local_batch, upload_api, progress, pbar
+                        )
 
                         ingest = self.documents.ingest_remote(
                             documents=up_docs,
@@ -269,7 +286,9 @@ class GroundX(GroundXBase):
                     current_batch_size += file_size
 
                 if local_batch:
-                    up_docs, progress = self._process_local(local_batch, upload_api, progress, pbar)
+                    up_docs, progress = self._process_local(
+                        local_batch, upload_api, progress, pbar
+                    )
 
                     ingest = self.documents.ingest_remote(
                         documents=up_docs,
@@ -283,10 +302,9 @@ class GroundX(GroundXBase):
                     pbar.update(progress)
 
                 return ingest
-        elif len(remote_documents) + len(local_documents) > MAX_BATCH_SIZE:
+        elif len(remote_documents) + len(local_documents) > max_n:
             raise ValueError("You have sent too many documents in this request")
 
-
         up_docs, _ = self._process_local(local_documents, upload_api, 0, None)
         remote_documents.extend(up_docs)
 
@@ -306,6 +324,7 @@ class GroundX(GroundXBase):
         upload_api: str = "https://api.eyelevel.ai/upload/file",
         callback_url: typing.Optional[str] = None,
         callback_data: typing.Optional[str] = None,
+        override_batch_size: typing.Optional[bool] = False,
         request_options: typing.Optional[RequestOptions] = None,
     ):
         """
@@ -360,9 +379,9 @@ class GroundX(GroundXBase):
             matched_files: typing.List[Path] = []
             for file in dir_path.rglob("*"):
                 for sd in split_doc(file):
-                    matched_files.append(sd)    
+                    matched_files.append(sd)
 
-            return matched_files      
+            return matched_files
 
         if bucket_id < 1:
             raise ValueError(f"Invalid bucket_id: {bucket_id}")
@@ -378,14 +397,28 @@ class GroundX(GroundXBase):
         current_batch: typing.List[Path] = []
         current_batch_size: int = 0
 
-        n = max(MIN_BATCH_SIZE, min(batch_size or MIN_BATCH_SIZE, MAX_BATCH_SIZE))
+        max_n = MAX_BATCH_SIZE
+        if override_batch_size:
+            max_n = 1000
+
+        n = max(MIN_BATCH_SIZE, min(batch_size or MIN_BATCH_SIZE, max_n))
 
         with tqdm(total=len(files), desc="Ingesting Files", unit="file") as pbar:
             for file in files:
                 file_size = file.stat().st_size
 
-                if (current_batch_size + file_size > MAX_BATCH_SIZE_BYTES) or (len(current_batch) >= n):
-                    self._upload_file_batch(bucket_id, current_batch, upload_api, callback_url, callback_data, request_options, pbar)
+                if (current_batch_size + file_size > MAX_BATCH_SIZE_BYTES) or (
+                    len(current_batch) >= n
+                ):
+                    self._upload_file_batch(
+                        bucket_id,
+                        current_batch,
+                        upload_api,
+                        callback_url,
+                        callback_data,
+                        request_options,
+                        pbar,
+                    )
                     current_batch = []
                     current_batch_size = 0
 
@@ -393,7 +426,15 @@ class GroundX(GroundXBase):
                 current_batch_size += file_size
 
             if current_batch:
-                self._upload_file_batch(bucket_id, current_batch, upload_api, callback_url, callback_data, request_options, pbar)
+                self._upload_file_batch(
+                    bucket_id,
+                    current_batch,
+                    upload_api,
+                    callback_url,
+                    callback_data,
+                    request_options,
+                    pbar,
+                )
 
     def _upload_file(
         self,
@@ -408,12 +449,13 @@ class GroundX(GroundXBase):
         presigned_info = get_presigned_url(endpoint, file_name, file_extension)
 
         upload_url = presigned_info["URL"]
-        headers = presigned_info.get("Header", {})
+        hd = presigned_info.get("Header", {})
         method = presigned_info.get("Method", "PUT").upper()
 
-        for key, value in headers.items():
+        headers: typing.Dict[str, typing.Any] = {}
+        for key, value in hd.items():
             if isinstance(value, list):
-                headers[key] = value[0]
+                headers[key.upper()] = value[0]
 
         try:
             with open(file_path, "rb") as f:
@@ -431,6 +473,9 @@ class GroundX(GroundXBase):
                 f"Upload failed: {upload_response.status_code} - {upload_response.text}"
             )
 
+        if "GX-HOSTED-URL" in headers:
+            return headers["GX-HOSTED-URL"]
+
         return strip_query_params(upload_url)
 
     def _process_local(
@@ -481,39 +526,62 @@ class GroundX(GroundXBase):
     ) -> typing.Tuple[IngestResponse, float]:
         completed_files: typing.Set[str] = set()
 
-        while (
-            ingest.ingest.status not in ["complete", "error", "cancelled"]
-        ):
+        while ingest.ingest.status not in ["complete", "error", "cancelled"]:
             time.sleep(3)
-            ingest = self.documents.get_processing_status_by_id(ingest.ingest.process_id)
+            ingest = self.documents.get_processing_status_by_id(
+                ingest.ingest.process_id
+            )
 
             if ingest.ingest.progress:
-                if ingest.ingest.progress.processing and ingest.ingest.progress.processing.documents:
+                if (
+                    ingest.ingest.progress.processing
+                    and ingest.ingest.progress.processing.documents
+                ):
                     for doc in ingest.ingest.progress.processing.documents:
-                        if doc.status in ["complete", "error", "cancelled"] and doc.document_id not in completed_files:
+                        if (
+                            doc.status in ["complete", "error", "cancelled"]
+                            and doc.document_id not in completed_files
+                        ):
                             pbar.update(0.75)
                             progress -= 0.75
                             completed_files.add(doc.document_id)
-                if ingest.ingest.progress.complete and ingest.ingest.progress.complete.documents:
+                if (
+                    ingest.ingest.progress.complete
+                    and ingest.ingest.progress.complete.documents
+                ):
                     for doc in ingest.ingest.progress.complete.documents:
-                        if doc.status in ["complete", "error", "cancelled"] and doc.document_id not in completed_files:
+                        if (
+                            doc.status in ["complete", "error", "cancelled"]
+                            and doc.document_id not in completed_files
+                        ):
                             pbar.update(0.75)
                             progress -= 0.75
                             completed_files.add(doc.document_id)
-                if ingest.ingest.progress.cancelled and ingest.ingest.progress.cancelled.documents:
+                if (
+                    ingest.ingest.progress.cancelled
+                    and ingest.ingest.progress.cancelled.documents
+                ):
                     for doc in ingest.ingest.progress.cancelled.documents:
-                        if doc.status in ["complete", "error", "cancelled"] and doc.document_id not in completed_files:
+                        if (
+                            doc.status in ["complete", "error", "cancelled"]
+                            and doc.document_id not in completed_files
+                        ):
                             pbar.update(0.75)
                             progress -= 0.75
                             completed_files.add(doc.document_id)
-                if ingest.ingest.progress.errors and ingest.ingest.progress.errors.documents:
+                if (
+                    ingest.ingest.progress.errors
+                    and ingest.ingest.progress.errors.documents
+                ):
                     for doc in ingest.ingest.progress.errors.documents:
-                        if doc.status in ["complete", "error", "cancelled"] and doc.document_id not in completed_files:
+                        if (
+                            doc.status in ["complete", "error", "cancelled"]
+                            and doc.document_id not in completed_files
+                        ):
                             pbar.update(0.75)
                             progress -= 0.75
                             completed_files.add(doc.document_id)
 
-
         if ingest.ingest.status in ["error", "cancelled"]:
             raise ValueError(f"Ingest failed with status: {ingest.ingest.status}")
 
@@ -531,7 +599,7 @@ class GroundX(GroundXBase):
     ) -> None:
         docs: typing.List[Document] = []
 
-        progress =  float(len(batch))
+        progress = float(len(batch))
         for file in batch:
             url = self._upload_file(upload_api, file)
             if file.suffix.lower() in SUFFIX_ALIASES:
@@ -567,7 +635,6 @@ class GroundX(GroundXBase):
             pbar.update(progress)
 
 
-
 class AsyncGroundX(AsyncGroundXBase):
     async def ingest(
         self,
@@ -576,6 +643,7 @@ class AsyncGroundX(AsyncGroundXBase):
         upload_api: str = "https://api.eyelevel.ai/upload/file",
         callback_url: typing.Optional[str] = None,
         callback_data: typing.Optional[str] = None,
+        override_batch_size: typing.Optional[bool] = False,
         request_options: typing.Optional[RequestOptions] = None,
     ) -> IngestResponse:
         """
@@ -630,7 +698,11 @@ class AsyncGroundX(AsyncGroundXBase):
         """
         remote_documents, local_documents = prep_documents(documents)
 
-        if len(remote_documents) + len(local_documents) > MAX_BATCH_SIZE:
+        max_n = MAX_BATCH_SIZE
+        if override_batch_size:
+            max_n = 1000
+
+        if len(remote_documents) + len(local_documents) > max_n:
             raise ValueError("You have sent too many documents in this request")
 
         if len(remote_documents) + len(local_documents) == 0:
@@ -682,12 +754,13 @@ class AsyncGroundX(AsyncGroundXBase):
         presigned_info = get_presigned_url(endpoint, file_name, file_extension)
 
         upload_url = presigned_info["URL"]
-        headers = presigned_info.get("Header", {})
+        hd = presigned_info.get("Header", {})
         method = presigned_info.get("Method", "PUT").upper()
 
-        for key, value in headers.items():
+        headers: typing.Dict[str, typing.Any] = {}
+        for key, value in hd.items():
             if isinstance(value, list):
-                headers[key] = value[0]
+                headers[key.upper()] = value[0]
 
         try:
             with open(file_path, "rb") as f:
@@ -705,4 +778,7 @@ class AsyncGroundX(AsyncGroundXBase):
                 f"Upload failed: {upload_response.status_code} - {upload_response.text}"
             )
 
+        if "GX-HOSTED-URL" in headers:
+            return headers["GX-HOSTED-URL"]
+
         return strip_query_params(upload_url)
